package eu.mulk.ducl;
import scala.sys.process._;

object Util {
  def prefix(exponent: Long) = {
    (exponent/3) match {
      case 0 => ""
      case 1 => "Ki"
      case 2 => "Mi"
      case 3 => "Gi"
      case 4 => "Ti"
      case 5 => "Ei"
      case 6 => "Pi"
      case 7 => "Zi"
      case 8 => "Yi"
    }
  }

  def log2(x: Double) = {
    scala.math.log(x)/scala.math.log(2)
  }
};

class Size(val n: Long) {
  val exponent : Long = scala.math.max(Util.log2(n.toDouble), 0).toLong/10
  val mantissa : Double = n.toDouble / scala.math.pow(1024, exponent);
  override def toString() = {
    "%5.1f %2sB".format(mantissa, Util.prefix(exponent*3))
  }
};

class Record(val isize: Long, val file: String) extends Comparable[Record] {
  val size = new Size(isize);
  override def toString() = {
    "%s\t%s".format(size, file)
  }
  override def compareTo(r: Record) = {
    (isize < r.isize, isize == r.isize) match {
      case (_,     true)  => 0
      case (true,  _)     => -1
      case (false, false) => 1
    }
  }
};

object DU {
  def main(args: Array[String]) = {
    val records = (Seq("du", "-k")++args).!!.split("\n").map((line) => {
      val Array(a,b) = line.split("\\s+", 2);
      new Record(a.toLong*1024,b)
    }).sorted.map(System.out.println _)
  }
};
